<?php
/**
 * @file
 * Contains Drupal\vardumper_block\VarDumper\VarDumperBlock.
 */

namespace Drupal\vardumper_block\Plugin\Block;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Session\SessionInterface;
use Drupal\Core\Block\BlockBase;

/**
 * Provides a 'Vardumper' block.
 *
 * @Block(
 *   id = "vardumper",
 *   admin_label = @Translation("Vardumper block"),
 * )
 */
class VarDumperBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The Session service.
   *
   * @var Session;
   */
  protected $session;

  /**
   * {@inheritDoc}.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, SessionInterface $session) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->session = $session;
  }

  /**
   * {@inheritDoc}.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('session')
    );
  }

  /**
   * {@inheritDoc}.
   */
  public function build() {
    /* @var \Symfony\Component\HttpFoundation\Session\Session $session */
    $session = $this->session;

    $items = [];
    foreach ($session->getFlashBag()->get('vardumper', array()) as $message) {
      $items[] = $message;
    }

    if ($items) {
      return [
        '#theme' => 'item_list',
        '#items' => $items,
        '#cache' => [
          'max-age' => 0,
        ],
      ];
    }
  }

}
